@@ -2,7 +2,7 @@ package Minilla::Profile::Default;
 use strict;
 use warnings;
 use utf8;
-use parent qw(Minilla::Profile::ModuleBuild);
+use parent qw(Minilla::Profile::ModuleBuildTiny);
 
 # The default profile is Module::Build.
 
